*****************************************
:mod:`mopidy.frontends.mpd` -- MPD server
*****************************************

.. automodule:: mopidy.frontends.mpd
    :synopsis: MPD server frontend


MPD dispatcher
==============

.. automodule:: mopidy.frontends.mpd.dispatcher
    :synopsis: MPD request dispatcher
    :members:


MPD protocol
============

.. automodule:: mopidy.frontends.mpd.protocol
    :synopsis: MPD protocol
    :members:


Audio output
------------

.. automodule:: mopidy.frontends.mpd.protocol.audio_output
    :synopsis: MPD protocol: audio output
    :members:


Channels
--------

.. automodule:: mopidy.frontends.mpd.protocol.channels
    :synopsis: MPD protocol: channels -- client to client communication
    :members:


Command list
------------

.. automodule:: mopidy.frontends.mpd.protocol.command_list
    :synopsis: MPD protocol: command list
    :members:


Connection
----------

.. automodule:: mopidy.frontends.mpd.protocol.connection
    :synopsis: MPD protocol: connection
    :members:


Current playlist
----------------

.. automodule:: mopidy.frontends.mpd.protocol.current_playlist
    :synopsis: MPD protocol: current playlist
    :members:


Music database
--------------

.. automodule:: mopidy.frontends.mpd.protocol.music_db
    :synopsis: MPD protocol: music database
    :members:


Playback
--------

.. automodule:: mopidy.frontends.mpd.protocol.playback
    :synopsis: MPD protocol: playback
    :members:


Reflection
----------

.. automodule:: mopidy.frontends.mpd.protocol.reflection
    :synopsis: MPD protocol: reflection
    :members:


Status
------

.. automodule:: mopidy.frontends.mpd.protocol.status
    :synopsis: MPD protocol: status
    :members:


Stickers
--------

.. automodule:: mopidy.frontends.mpd.protocol.stickers
    :synopsis: MPD protocol: stickers
    :members:


Stored playlists
----------------

.. automodule:: mopidy.frontends.mpd.protocol.stored_playlists
    :synopsis: MPD protocol: stored playlists
    :members:
